@@ -1,4 +1,4 @@
-/* $Id: directory-handle.cc,v 1.10 2004/02/13 18:22:29 murrayc Exp $ */               
+/* $Id: directory-handle.cc,v 1.11 2005/04/15 10:56:16 murrayc Exp $ */               
 
 /* Copyright 2003 gnome-vfsmm Development Team
  *
@@ -133,6 +133,16 @@ Glib::RefPtr<FileInfo> DirectoryHandle::read_next(bool& file_exists) throw(excep
   return cppFileInfo;
 }
 
+Glib::RefPtr<FileInfo> DirectoryHandle::read_next() throw(exception)
+{
+  bool file_exists = true;
+  Glib::RefPtr<FileInfo> refFileInfo = read_next(file_exists);
+  if (!file_exists)
+    refFileInfo.clear(); //ref is now null, indicating read failed.
+
+  return refFileInfo;
+}
+
 void DirectoryHandle::visit(const Glib::ustring& uri, FileInfoOptions info_options, DirectoryVisitOptions visit_options, const SlotVisit& slot) throw(exception)
 {
   SignalProxy_Visit proxy(slot);
