@@ -1,4 +1,4 @@
-/* $Id: handle.h,v 1.3 2003/04/30 18:25:18 murrayc Exp $ */
+/* $Id: handle.h,v 1.9 2003/07/21 20:54:05 mxpxpod Exp $ */
 
 /* Copyright 2003 gnome-vfsmm Development Team
  *
@@ -23,10 +23,13 @@
 
 #include <glibmm.h>
 
+#include <libgnomevfs/gnome-vfs-ops.h>
+
 #include <libgnomevfsmm/uri.h>
+#include <libgnomevfsmm/exception.h>
 #include <libgnomevfsmm/file-info.h>
 #include <libgnomevfsmm/enums.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
+#include <libgnomevfsmm/types.h>
 
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
@@ -45,62 +48,60 @@ public:
   Handle();
   virtual ~Handle();
   
-  void open(const Glib::ustring& text_uri, GnomeVFSOpenMode open_mode) throw(exception);
-  void open(const Glib::RefPtr<const Uri>& uri, GnomeVFSOpenMode open_mode) throw(exception);
+  void open(const Glib::ustring& text_uri, OpenMode open_mode) throw(exception);
+  void open(const Glib::RefPtr<const Uri>& uri, OpenMode open_mode) throw(exception);
 
-  void create(const Glib::ustring& text_uri, GnomeVFSOpenMode open_mode, bool exclusive, guint perm) throw(exception);
-
-  void create(const Glib::RefPtr<const Uri>& uri, GnomeVFSOpenMode open_mode, bool exclusive, guint perm) throw(exception);
+  void create(const Glib::ustring& text_uri, OpenMode open_mode, bool exclusive, guint permissions) throw(exception);
+  void create(const Glib::RefPtr<const Uri>& uri, OpenMode open_mode, bool exclusive, guint permissions) throw(exception);
 
   void close() throw(exception);
 
-  GnomeVFSFileSize read(gpointer buffer, GnomeVFSFileSize bytes) throw(exception);
+  FileSize read(gpointer buffer, FileSize bytes) throw(exception);
 
-  GnomeVFSFileSize write(gconstpointer buffer, GnomeVFSFileSize bytes) throw(exception);
+  FileSize write(gconstpointer buffer, FileSize bytes) throw(exception);
 
-  void seek(GnomeVFSSeekPosition whence, GnomeVFSFileOffset offset) throw(exception);
+  void seek(SeekPosition whence, FileOffset offset) throw(exception);
 
-  void tell(GnomeVFSFileSize& offset_return) throw(exception);
+  FileSize tell() throw(exception);
   
   static Glib::RefPtr<FileInfo> get_file_info(const Glib::ustring& text_uri, FileInfoOptions options = FILE_INFO_DEFAULT) throw(exception);
 
   Glib::RefPtr<FileInfo> get_file_info(FileInfoOptions options = FILE_INFO_DEFAULT) const throw(exception);
 
   
-  static void truncate(const Glib::ustring& text_uri, GnomeVFSFileSize length) throw(exception);
-  void truncate(GnomeVFSFileSize length) throw(exception);
+  static void truncate(const Glib::ustring& text_uri, FileSize length) throw(exception);
+  static void truncate(const Glib::RefPtr<const Uri>& uri, FileSize length) throw(exception);
+  void truncate(FileSize length) throw(exception);
 
-  static void make_directory(const Glib::ustring& text_uri, guint perm) throw(exception);
+  static void make_directory(const Glib::ustring& text_uri, guint permissions) throw(exception);
+  static void make_directory(const Glib::RefPtr<const Uri>& uri, guint permissions) throw(exception);
 
   static void remove_directory(const Glib::ustring& text_uri) throw(exception);
+  static void remove_directory(const Glib::RefPtr<const Uri>& uri) throw(exception);
 
-  void create_symbolic_link(const Glib::RefPtr<const Uri>& uri, const Glib::ustring& target_reference) throw(exception);
   static void unlink(const Glib::ustring& text_uri) throw(exception);
+  static void unlink(const Glib::RefPtr<const Uri>& uri) throw(exception);
 
   static void move(const Glib::ustring& old_text_uri, const Glib::ustring& new_text_uri, bool force_replace) throw(exception);
+  static void move(const Glib::RefPtr<const Uri>& old_uri, const Glib::RefPtr<const Uri>& new_uri, bool force_replace) throw(exception);
    
   static bool check_same_fs(const Glib::ustring& source, const Glib::ustring& target) throw(exception);
+  static bool check_same_fs(const Glib::RefPtr<const Uri>& source, const Glib::RefPtr<const Uri>& target) throw(exception);
 
-  bool gnome_vfs_uri_exists(const Glib::RefPtr<const Uri>& uri) throw(exception);
+  bool uri_exists(const Glib::RefPtr<const Uri>& uri) throw(exception);
 
-  static void set_file_info(const Glib::ustring& text_uri, const Glib::RefPtr<const FileInfo>& info, GnomeVFSSetFileInfoMask mask) throw(exception);
-
-  //TODO: Use a SigC::Slot.
-  void monitor_add(GnomeVFSMonitorHandle **handle, const Glib::ustring& text_uri, GnomeVFSMonitorType monitor_type, GnomeVFSMonitorCallback callback, gpointer user_data) throw(exception);
-
-  static void monitor_cancel(GnomeVFSMonitorHandle *handle) throw(exception);
+  static void set_file_info(const Glib::ustring& text_uri, const Glib::RefPtr<const FileInfo>& info, SetFileInfoMask mask) throw(exception);
+  static void set_file_info(const Glib::RefPtr<const Uri>& uri, const Glib::RefPtr<const FileInfo>& info, SetFileInfoMask mask) throw(exception);
 
   void file_control(const Glib::ustring& operation, gpointer operation_data) throw(exception);
-
+  
   
   GnomeVFSHandle* gobj();
   const GnomeVFSHandle* gobj() const;  
 
 
 protected:
-
-  static void handle_result(GnomeVFSResult result) throw(exception);
-  
+ 
   GnomeVFSHandle* gobj_;
 };
 
